"""Class file for the entity SolarHistory."""


class SolarHistory:
    """The entity for SolarHistory."""

    id: int | None
    serial_number: str | None
    battery_discharge: str | None
    battery_charge: str | None
    battery_capacity: str | None
    battery_stored_power: str | None
    total_load_active_power: str | None
    realtime_solar: str | None
    timestamp: str | None
    solar_profile: str | None
    daily_yeild: str | None

    def __init__(self, data) -> None:  # noqa: D107
        self.id = data.get("id")
        self.serial_number = data.get("serialNumber")
        self.battery_discharge = data.get("batteryDischarge")
        self.battery_charge = data.get("batteryCharge")
        self.battery_capacity = data.get("batteryCapacity")
        self.battery_stored_power = data.get("batteryStoredPower")
        self.total_load_active_power = data.get("totalLoadActivePower")
        self.realtime_solar = data.get("realtimeSolar")
        self.timestamp = data.get("timestamp")
        self.solar_profile = data.get("solarProfile")
        self.daily_yeild = data.get("dailyYeild")

    def to_dict(self):
        """Convert SolarHistory object to a dictionary."""
        return {
            "id": self.id,
            "serial_number": self.serial_number,
            "battery_discharge": self.battery_discharge,
            "battery_charge": self.battery_charge,
            "battery_capacity": self.battery_capacity,
            "battery_stored_power": self.battery_stored_power,
            "total_load_active_power": self.total_load_active_power,
            "realtime_solar": self.realtime_solar,
            "timestamp": self.timestamp,
            "solar_profile": self.solar_profile,
            "daily_yeild": self.daily_yeild,
        }



import setuptools

setuptools.setup(
    name="trest_solar",
    version="1.0.1",
    author="LordMax2",
    description="Package to integrate Trest Solar in your Python project.",
    packages=["trest_solar"]
)


import json 

import aiohttp 
from trest_identity import TrestIdentityService

class CloudSolarTrestService:
    """The class representing the Api of the Cloud Solar Trest application."""

    def __init__(self, username: str, password: str) -> None:
        """Init the class."""
        self.base_url = "https://cloud.solar.trest.se:443"
        self.trest_identity_service = TrestIdentityService(username, password)

    async def get_latest_solar_history_async(self) -> str:
        """Get the latest solar history from the Api."""
        await self.trest_identity_service.renew_token_async()

        headers = {"X-Token": self.trest_identity_service.token}

        async with aiohttp.ClientSession() as session, session.get(
            self.base_url + "/api/v1/solar/getlatesthistory",
            headers=headers,
            timeout=3,
        ) as response:
            response_text = await response.text()

            return json.loads(response_text)
